import { IFileChange, FileChangeType } from '../interfaces';
import { URI } from '@vscode/monaco-editor/esm/vs/base/common/uri';
export declare class FileChangesEvent {
    private _changes;
    constructor(changes: IFileChange[]);
    readonly changes: IFileChange[];
    /**
     * Returns true if this change event contains the provided file with the given change type (if provided). In case of
     * type DELETED, this method will also return true if a folder got deleted that is the parent of the
     * provided file path.
     */
    contains(resource: URI, type?: FileChangeType): boolean;
    /**
     * Returns the changes that describe added files.
     */
    getAdded(): IFileChange[];
    /**
     * Returns if this event contains added files.
     */
    gotAdded(): boolean;
    /**
     * Returns the changes that describe deleted files.
     */
    getDeleted(): IFileChange[];
    /**
     * Returns if this event contains deleted files.
     */
    gotDeleted(): boolean;
    /**
     * Returns the changes that describe updated files.
     */
    getUpdated(): IFileChange[];
    /**
     * Returns if this event contains updated files.
     */
    gotUpdated(): boolean;
    private getOfType;
    private hasType;
}
