import { ITreeData_Input } from './generated-models';
import { URI } from '@vscode/monaco-editor/esm/vs/base/common/uri';
export interface IFilesTreeService {
    /**
     * Set Tree Data in the cache. This will make the UI's tree data to sync
     * to Cached data.
     *
     * @param {ITreeData_Input[]} newData
     * @param {(ITreeData_Input & { treeData: any, resource: URI})} originalData
     * @memberof IFilesTreeService
     */
    setTreeData(newData: ITreeData_Input[], originalData: ITreeData_Input & {
        treeData: any;
        resource: URI;
    }): any;
    /**
     * Load the tree data, if it doesn't exist in cache,
     * it will load from backend.
     *
     * @param {URI} resource
     * @memberof IFilesTreeService
     */
    loadTreeData(resource: URI): any;
    /**
     * Get the Tree Data from the cache.
     *
     * @param {URI} resource
     * @memberof IFilesTreeService
     */
    getTreeData(resource: URI): any;
    /**
     * Reloads the TreeData from the backend
     *
     * @param {URI} resource
     * @memberof IFilesTreeService
     */
    reloadTreeData(resource: URI): any;
}
